v0.3.0 (2019-03-08)
===================

- Add testing account option for gce account add.
  [\15](https://github.com/SUSE-Enceladus/mash/pull/15)

v0.2.0 (2019-02-22)
===================

- Add readthedocs documentation.
  [\11](https://github.com/SUSE-Enceladus/mash/pull/11)
- Move default mash client config file.
  [\12](https://github.com/SUSE-Enceladus/mash/pull/12)
- Add ec2 account has a single target region.
  [\13](https://github.com/SUSE-Enceladus/mash/pull/13)
- Re-word cli option help messages.
  [\14](https://github.com/SUSE-Enceladus/mash/pull/14)

v0.1.0 (2019-02-04)
===================

- Update mash job delete.
  [\#5](https://github.com/SUSE-Enceladus/mash/pull/5)
- Update account delete.
  [\#6](https://github.com/SUSE-Enceladus/mash/pull/6)
- Add integration test suite.
  [\#9](https://github.com/SUSE-Enceladus/mash/pull/9)
- Remove references to provider.
  [\#10](https://github.com/SUSE-Enceladus/mash/pull/10)

v0.0.2 (2018-11-15)
===================

- Cleanup spec requirements.
  [\#2](https://github.com/SUSE-Enceladus/mash/pull/2)
- Handle Azure source and destination storage options.
  [\#3](https://github.com/SUSE-Enceladus/mash/pull/3)
- Add GCE add account endpoint.
  [\#4](https://github.com/SUSE-Enceladus/mash/pull/4)
- Use required options instead of positional args.
  [\#7](https://github.com/SUSE-Enceladus/mash/pull/7)
  [\#8](https://github.com/SUSE-Enceladus/mash/pull/8)

v0.0.1 (2018-08-24)
===================

- Initial release.
